@@ -784,8 +784,20 @@ class DeployOvercloud(command.Command):
         parser.add_argument(
             '--config-download',
             action='store_true',
+            default=True,
+            help=_('Run deployment via config-download mechanism. This is '
+                   'now the default, and this CLI options may be removed in '
+                   'the future.')
+        )
+        parser.add_argument(
+            '--no-config-download',
+            '--stack-only',
+            action='store_false',
             default=False,
-            help=_('Run deployment via config-download mechanism')
+            dest='config_download',
+            help=_('Disable the config-download workflow and only create '
+                   'the stack and associated OpenStack resources. No '
+                   'software configuration will be applied.')
         )
         parser.add_argument(
             '--output-dir',
